sampleFromSeries abstract method
Returns a dataframe, sampled from series that are obtained from the
series indices or series names.
If indices are specified, names parameter will be ignored.
Series indices or series names may be repeating.
Implementation
DataFrame sampleFromSeries({
Iterable<int> indices,
Iterable<String> names,
});